@@ -14,9 +14,7 @@ class String
   end
 
   def number?
-    true if Integer(self)
-  rescue StandardError
-    false
+    !!Integer(self, exception: false)
   end
 
   def initial
